@@ -3,7 +3,7 @@ Soft Potato pip version
 
 """
 
-__version__ = "0.10"
+__version__ = "0.11"
 __author__ = 'Oliver Rodriguez'
 
-__all__ = ['tech', 'calc']
\ No newline at end of file
+__all__ = ['tech', 'calc', 'plot']
\ No newline at end of file
